@@ -34,8 +34,8 @@ class KCM_TELEPATHY_ACCOUNTS_EXPORT AbstractAccountUiPlugin : public QObject
     Q_OBJECT
 
 public:
-    explicit AbstractAccountUiPlugin(QObject *parent = 0);
-    virtual ~AbstractAccountUiPlugin();
+    explicit AbstractAccountUiPlugin(QObject *parent = nullptr);
+    ~AbstractAccountUiPlugin() override;
 
     virtual const QMap<QString, QString> &providedProtocols() const;
 
